@@ -226,7 +226,6 @@ b_wincred_init <- function(self, private, keyring) {
 
 #' Get a key from a Wincred keyring
 #'
-#' @param backend Backend object.
 #' @param service Service name. Must not be empty.
 #' @param username Username. Might be empty.
 #'
@@ -402,7 +401,7 @@ b_wincred_list <- function(self, private, service, keyring) {
 
 b_wincred_keyring_create <- function(self, private, keyring, password) {
   password <- password %||% get_pass()
-  if (is.null(password)) stop("Aborted craeting keyring")
+  if (is.null(password)) stop("Aborted creating keyring")
   private$keyring_create_direct(keyring, password)
   invisible(self)
 }
